@@ -4,7 +4,10 @@
  * return XML for ajax
  * Frank Habermann
  */
- 
+
+if(!is_file("config/config.inc.php")) {
+	exit();
+}
 
 // load requiered files
 require_once("config/config.inc.php");
