@@ -1,3 +1,13 @@
+CREATE TABLE `access` (
+        `id` int(11) NOT NULL auto_increment,
+        `table_name` varchar(255) NOT NULL DEFAULT '',
+        `belongs_to` int(11) NOT NULL DEFAULT 0,
+        `owner_group` varchar(5) NOT NULL DEFAULT '',
+        `owner_group_id` int(11) NOT NULL DEFAULT 0,
+        `rights` int(11) NOT NULL DEFAULT 0,
+	PRIMARY KEY  (`id`)
+) TYPE=MyISAM AUTO_INCREMENT=1 ;
+
 CREATE TABLE `content` (
   `id` int(11) NOT NULL auto_increment,
   `title` varchar(255) default NULL,
@@ -42,6 +52,7 @@ CREATE TABLE `files` (
   `filetype` varchar(255) default 'application/octet-stream',
   `owner` int(11) NOT NULL default '0',
   `date` timestamp NOT NULL,
+  `counter` int(11) NOT NULL default '0',
   `deleted` int(1) NOT NULL default '0',
   PRIMARY KEY  (`id`),
   KEY `belongs_to` (`belongs_to`),
@@ -61,6 +72,7 @@ CREATE TABLE `tree` (
   `id` int(11) NOT NULL auto_increment,
   `belongs_to` int(11) NOT NULL default '0',
   `title` varchar(255) NOT NULL default '',
+  `tooltip` varchar(255) NOT NULL default '',
   `alias` varchar(255) NOT NULL default '',
   `contentcollapsed` int(1) NOT NULL default '0',
   `owner` int(11) NOT NULL default '0',
@@ -76,6 +88,8 @@ CREATE TABLE `tree` (
   `subinherituserrights` int(11) NOT NULL default '0',
   `subinheritgrouprights` int(11) NOT NULL default '0',
   `subinheritotherrights` int(11) NOT NULL default '0',
+  `symlink` int(11) NOT NULL default '0',
+  `sorting` int(11) NOT NULL default '0',
   `deleted` int(1) NOT NULL default '0',
   PRIMARY KEY  (`id`),
   KEY `belongs_to` (`belongs_to`),
@@ -127,7 +141,7 @@ KEY `active` (`active`)
 CREATE TABLE `settings` (
 `id` INT NOT NULL AUTO_INCREMENT ,
 `name` VARCHAR( 255 ) NOT NULL ,
-`value` VARCHAR( 255 ) NOT NULL ,
+`value` text NOT NULL ,
 `description` VARCHAR( 255) NOT NULL DEFAULT '',
 `selection` VARCHAR(255) NOT NULL DEFAULT '',
 PRIMARY KEY ( `id` ) ,
@@ -163,6 +177,8 @@ INSERT INTO `extensions` (`keyname`, `active`, `admin`) VALUES ('admin_info', 1,
 # INSERT INTO `extensions` (`keyname`, `active`, `admin`) VALUES ('admin_install', 1, 1);
 # INSERT INTO `extensions` (`keyname`, `active`, `admin`) VALUES ('admin_update', 1, 1);
 INSERT INTO `extensions` (`keyname`, `active`, `admin`) VALUES ('admin_config', 1, 1);
+INSERT INTO `extensions` (`keyname`, `active`, `admin`) VALUES ('fckeditor', 1, 0);
+INSERT INTO `extensions` (`keyname`, `active`, `admin`) VALUES ('tinymce', 0, 0);
 
 # insert default settings
 INSERT INTO `settings` (`name`, `value`, `description`, `selection`) VALUES ('login.delay', '30', 'setting login delay', '');
@@ -170,13 +186,6 @@ INSERT INTO `settings` (`name`, `value`, `description`, `selection`) VALUES ('lo
 INSERT INTO `settings` (`name`, `value`, `description`, `selection`) VALUES ('knowledgeroot.charset', 'UTF-8', 'set charset', '');
 INSERT INTO `settings` (`name`, `value`, `description`, `selection`) VALUES ('knowledgeroot.language', 'en', 'set default language', '');
 INSERT INTO `settings` (`name`, `value`, `description`, `selection`) VALUES ('knowledgeroot.language_dropdown', '0', 'show language dropdown', '');
-INSERT INTO `settings` (`name`, `value`, `description`, `selection`) VALUES ('knowledgeroot.availablelanguages.1', 'en', '', '');
-INSERT INTO `settings` (`name`, `value`, `description`, `selection`) VALUES ('knowledgeroot.availablelanguages.2', 'de', '', '');
-INSERT INTO `settings` (`name`, `value`, `description`, `selection`) VALUES ('knowledgeroot.availablelanguages.3', 'pt-br', '', '');
-INSERT INTO `settings` (`name`, `value`, `description`, `selection`) VALUES ('knowledgeroot.availablelanguages.4', 'nl', '', '');
-INSERT INTO `settings` (`name`, `value`, `description`, `selection`) VALUES ('knowledgeroot.availablelanguages.5', 'ja', '', '');
-INSERT INTO `settings` (`name`, `value`, `description`, `selection`) VALUES ('knowledgeroot.availablelanguages.6', 'es', '', '');
-INSERT INTO `settings` (`name`, `value`, `description`, `selection`) VALUES ('knowledgeroot.availablelanguages.7', 'ru', '', '');
 INSERT INTO `settings` (`name`, `value`, `description`, `selection`) VALUES ('htmleditor.use', '1', 'enable rte editor', '');
 INSERT INTO `settings` (`name`, `value`, `description`, `selection`) VALUES ('htmleditor.editor', 'fckeditor', 'choose fckeditor or tinymce', '');
 INSERT INTO `settings` (`name`, `value`, `description`, `selection`) VALUES ('htmleditor.tinymce.cols', '75' , 'set cols for textarea in tinymce', '');
@@ -198,6 +207,7 @@ INSERT INTO `settings` (`name`, `value`, `description`, `selection`) VALUES ('kn
 INSERT INTO `settings` (`name`, `value`, `description`, `selection`) VALUES ('knowledgeroot.uploadfolder', 'uploads/', 'set upload folder', '');
 INSERT INTO `settings` (`name`, `value`, `description`, `selection`) VALUES ('knowledgeroot.uploadserverpath', 'auto', 'set upload server path', '');
 INSERT INTO `settings` (`name`, `value`, `description`, `selection`) VALUES ('knowledgeroot.defaultpage', '', 'set id of default page', '');
+INSERT INTO `settings` (`name`, `value`, `description`, `selection`) VALUES ('knowledgeroot.recursivdelete', '2', 'set recusriv delete, 2 - only admins; 1 - all users with login, 0 - all users', '');
 INSERT INTO `settings` (`name`, `value`, `description`, `selection`) VALUES ('email.notification', '0', 'enable email notification', '');
 INSERT INTO `settings` (`name`, `value`, `description`, `selection`) VALUES ('email.recipients', '', 'set recipients', '');
 INSERT INTO `settings` (`name`, `value`, `description`, `selection`) VALUES ('email.type', 'html', 'enable html mails', '');
@@ -212,4 +222,22 @@ INSERT INTO `settings` (`name`, `value`, `description`, `selection`) VALUES ('de
 INSERT INTO `settings` (`name`, `value`, `description`, `selection`) VALUES ('pagealias.use', '1', 'enable pagealias', '');
 INSERT INTO `settings` (`name`, `value`, `description`, `selection`) VALUES ('pagealias.rights', '2', 'set rights to edit the alias', '');
 INSERT INTO `settings` (`name`, `value`, `description`, `selection`) VALUES ('pagealias.static', '0', 'enable of using static links', '');
-INSERT INTO `settings` (`name`, `value`, `description`, `selection`) VALUES ('knowledgeroot.maxfilesize', '5242880', 'set maxfilesize for uploads', '');
\ No newline at end of file
+INSERT INTO `settings` (`name`, `value`, `description`, `selection`) VALUES ('knowledgeroot.maxfilesize', '5242880', 'set maxfilesize for uploads', '');
+INSERT INTO `settings` (`name`, `value`, `description`, `selection`) VALUES ('downloads.static', '0', 'enable static download links', '');
+INSERT INTO `settings` (`name`, `value`, `description`, `selection`) VALUES ('menu.order.self', '0', 'enable self order of tree elements', '');
+INSERT INTO `settings` (`name`, `value`, `description`, `selection`) VALUES ('menu.context', '1', 'enable/disable context menus', '');
+INSERT INTO `settings` (`name`, `value`, `description`, `selection`) VALUES ('menu.dragdrop', '1', 'enable/disable drag and drop in tree', '');
+INSERT INTO `settings` (`name`, `value`, `description`, `selection`) VALUES ('menu.edittooltiptext', '0', 'enable/disable edit of tooltiptext of tree element', '');
+INSERT INTO `settings` (`name`, `value`, `description`, `selection`) VALUES ('session.handle', '0', 'enable handling of sessin', '');
+INSERT INTO `settings` (`name`, `value`, `description`, `selection`) VALUES ('session.lifetime', '60', 'lifetime of session in minutes', '');
+INSERT INTO `settings` (`name`, `value`, `description`, `selection`) VALUES ('session.checkIP', '0', 'check ip of session', '');
+INSERT INTO `settings` (`name`, `value`, `description`, `selection`) VALUES ('session.checkBrowser', '0', 'check browser of session', '');
+INSERT INTO `settings` (`name`, `value`, `description`, `selection`) VALUES ('session.onlyCookies', '0', 'allow only cookie sessions', '');
+INSERT INTO `settings` (`name`, `value`, `description`, `selection`) VALUES ('menu.showcounter', '1', 'enable/disable counting of tree items', '');
+INSERT INTO `settings` (`name`, `value`, `description`, `selection`) VALUES ('content.showcounter', '1', 'enable/disable counting of content items', '');
+INSERT INTO `settings` (`name`, `value`, `description`, `selection`) VALUES ('menu.defaultlayout', '0', 'enable/disable a default layout of the tree', '');
+INSERT INTO `settings` (`name`, `value`, `description`, `selection`) VALUES ('menu.defaultlayoutarray', '', 'serialized array with default layout of tree - should not be edit', '');
+INSERT INTO `settings` (`name`, `value`, `description`, `selection`) VALUES ('menu.showsourceforgelogo', '0', 'show sourceforge logo', '');
+INSERT INTO `settings` (`name`, `value`, `description`, `selection`) VALUES ('knowledgeroot.showlogo', '0', 'show knowledgeroot logo instead of texttitle', '');
+INSERT INTO `settings` (`name`, `value`, `description`, `selection`) VALUES ('version', '0.9.9', 'knowledgeroot version - do not edit! - it only shows the database version of knowledgeroot', '');
+INSERT INTO `settings` (`name`, `value`, `description`, `selection`) VALUES ('baseurl', '', 'base url for knowledgeroot', '');
