@@ -2,6 +2,15 @@ BEGIN;
 
 CREATE SEQUENCE seq_knowledge;
 
+CREATE TABLE access (
+	id integer PRIMARY KEY DEFAULT nextval('seq_knowledge'),
+	table_name varchar(255) DEFAULT '',
+	belongs_to integer DEFAULT 0,
+        owner_group varchar(5) DEFAULT '',
+        owner_group_id integer DEFAULT 0,
+        rights integer DEFAULT 0
+);
+
 CREATE TABLE content (
 	id integer PRIMARY KEY DEFAULT nextval('seq_knowledge'),
 	title varchar(255) DEFAULT '',
@@ -30,6 +39,7 @@ CREATE TABLE tree (
 	id integer PRIMARY KEY DEFAULT nextval('seq_knowledge'),
 	belongs_to integer DEFAULT 0,
 	title varchar(255) DEFAULT '',
+	tooltip varchar(255) DEFAULT '',
 	alias varchar(255) DEFAULT '',
 	contentcollapsed integer DEFAULT 0,
 	owner integer DEFAULT 0,
@@ -45,6 +55,8 @@ CREATE TABLE tree (
 	subinherituserrights integer DEFAULT 0,
 	subinheritgrouprights integer DEFAULT 0,
 	subinheritotherrights integer DEFAULT 0,
+	symlink integer DEFAULT 0,
+	sorting integer DEFAULT 0,
 	deleted integer DEFAULT 0
 );
 
@@ -57,6 +69,7 @@ CREATE TABLE files (
 	filetype varchar(255) DEFAULT 'application/octet-stream',
 	owner integer DEFAULT 0,
 	date timestamp DEFAULT now(),
+	counter integer DEFAULT 0,
 	deleted integer DEFAULT 0
 );
 
@@ -99,7 +112,7 @@ CREATE TABLE extensions (
 CREATE TABLE settings (
 	id integer PRIMARY KEY DEFAULT nextval('seq_knowledge'),
 	name varchar(255) NOT NULL,
-	value varchar(255) DEFAULT '',
+	value text DEFAULT '',
 	description varchar(255) NOT NULL DEFAULT '',
 	selection varchar(255) NOT NULL DEFAULT '',
 	UNIQUE (name)
@@ -123,19 +136,14 @@ INSERT INTO extensions (keyname, active, admin) VALUES ('admin_info', 1, 1);
 -- INSERT INTO extensions (keyname, active, admin) VALUES ('admin_install', 1, 1);
 -- INSERT INTO extensions (keyname, active, admin) VALUES ('admin_update', 1, 1);
 INSERT INTO extensions (keyname, active, admin) VALUES ('admin_config', 1, 1);
+INSERT INTO extensions (keyname, active, admin) VALUES ('fckeditor', 1, 0);
+INSERT INTO extensions (keyname, active, admin) VALUES ('tinymce', 0, 0);
 
 INSERT INTO settings (name, value, description, selection) VALUES ('login.delay', '30', 'setting login delay', '');
 INSERT INTO settings (name, value, description, selection) VALUES ('login.max', '50', 'setting max login', '');
 INSERT INTO settings (name, value, description, selection) VALUES ('knowledgeroot.charset', 'UTF-8', 'set charset', '');
 INSERT INTO settings (name, value, description, selection) VALUES ('knowledgeroot.language', 'en', 'set default language', '');
 INSERT INTO settings (name, value, description, selection) VALUES ('knowledgeroot.language_dropdown', '0', 'show language dropdown', '');
-INSERT INTO settings (name, value, description, selection) VALUES ('knowledgeroot.availablelanguages.1', 'en', '', '');
-INSERT INTO settings (name, value, description, selection) VALUES ('knowledgeroot.availablelanguages.2', 'de', '', '');
-INSERT INTO settings (name, value, description, selection) VALUES ('knowledgeroot.availablelanguages.3', 'pt-br', '', '');
-INSERT INTO settings (name, value, description, selection) VALUES ('knowledgeroot.availablelanguages.4', 'nl', '', '');
-INSERT INTO settings (name, value, description, selection) VALUES ('knowledgeroot.availablelanguages.5', 'ja', '', '');
-INSERT INTO settings (name, value, description, selection) VALUES ('knowledgeroot.availablelanguages.6', 'es', '', '');
-INSERT INTO settings (name, value, description, selection) VALUES ('knowledgeroot.availablelanguages.7', 'ru', '', '');
 INSERT INTO settings (name, value, description, selection) VALUES ('htmleditor.use', '1', 'enable rte editor', '');
 INSERT INTO settings (name, value, description, selection) VALUES ('htmleditor.editor', 'fckeditor', 'choose fckeditor or tinymce', '');
 INSERT INTO settings (name, value, description, selection) VALUES ('htmleditor.tinymce.cols', '75' , 'set cols for textarea in tinymce', '');
@@ -157,6 +165,7 @@ INSERT INTO settings (name, value, description, selection) VALUES ('knowledgeroo
 INSERT INTO settings (name, value, description, selection) VALUES ('knowledgeroot.uploadfolder', 'uploads/', 'set upload folder', '');
 INSERT INTO settings (name, value, description, selection) VALUES ('knowledgeroot.uploadserverpath', 'auto', 'set upload server path', '');
 INSERT INTO settings (name, value, description, selection) VALUES ('knowledgeroot.defaultpage', '', 'set id of default page', '');
+INSERT INTO settings (name, value, description, selection) VALUES ('knowledgeroot.recursivdelete', '2', 'set recusriv delete, 2 - only admins; 1 - all users with login, 0 - all users', '');
 INSERT INTO settings (name, value, description, selection) VALUES ('email.notification', '0', 'enable email notification', '');
 INSERT INTO settings (name, value, description, selection) VALUES ('email.recipients', '', 'set recipients', '');
 INSERT INTO settings (name, value, description, selection) VALUES ('email.type', 'html', 'enable html mails', '');
@@ -172,6 +181,24 @@ INSERT INTO settings (name, value, description, selection) VALUES ('pagealias.us
 INSERT INTO settings (name, value, description, selection) VALUES ('pagealias.rights', '2', 'set rights to edit the alias', '');
 INSERT INTO settings (name, value, description, selection) VALUES ('pagealias.static', '0', 'enable of using static links', '');
 INSERT INTO settings (name, value, description, selection) VALUES ('knowledgeroot.maxfilesize', '5242880', 'set maxfilesize for uploads', '');
+INSERT INTO settings (name, value, description, selection) VALUES ('downloads.static', '0', 'enable static download links', '');
+INSERT INTO settings (name, value, description, selection) VALUES ('menu.order.self', '0', 'enable self ordering of tree elments', '');
+INSERT INTO settings (name, value, description, selection) VALUES ('menu.context', '1', 'enable/disable contextmenus', '');
+INSERT INTO settings (name, value, description, selection) VALUES ('menu.dragdrop', '1', 'enable/disable drag and drop in tree', '');
+INSERT INTO settings (name, value, description, selection) VALUES ('menu.edittooltiptext', '0', 'enable/disable edit of tooltiptext of tree element', '');
+INSERT INTO settings (name, value, description, selection) VALUES ('session.handle', '0', 'enable handling of sessin', '');
+INSERT INTO settings (name, value, description, selection) VALUES ('session.lifetime', '60', 'lifetime of session in minutes', '');
+INSERT INTO settings (name, value, description, selection) VALUES ('session.checkIP', '0', 'check ip of session', '');
+INSERT INTO settings (name, value, description, selection) VALUES ('session.checkBrowser', '0', 'check browser of session', '');
+INSERT INTO settings (name, value, description, selection) VALUES ('session.onlyCookies', '0', 'allow only cookie sessions', '');
+INSERT INTO settings (name, value, description, selection) VALUES ('menu.showcounter', '1', 'enable/disable counting of tree items', '');
+INSERT INTO settings (name, value, description, selection) VALUES ('content.showcounter', '1', 'enable/disable counting of content items', '');
+INSERT INTO settings (name, value, description, selection) VALUES ('menu.defaultlayout', '0', 'enable/disable a default layout of the tree', '');
+INSERT INTO settings (name, value, description, selection) VALUES ('menu.defaultlayoutarray', '', 'serialized array with default layout of tree - should not be edit', '');
+INSERT INTO settings (name, value, description, selection) VALUES ('menu.showsourceforgelogo', '0', 'show sourceforge logo', '');
+INSERT INTO settings (name, value, description, selection) VALUES ('knowledgeroot.showlogo', '0', 'show knowledgeroot logo instead of texttitle', '');
+INSERT INTO settings (name, value, description, selection) VALUES ('version', '0.9.9', 'knowledgeroot version - do not edit! - it only shows the database version of knowledgeroot', '');
+INSERT INTO settings (name, value, description, selection) VALUES ('baseurl', '', 'base url for knowledgeroot', '');
 
 CREATE INDEX idx_content ON content USING btree (belongs_to);
 CREATE INDEX idx_content_owner ON content USING btree (owner);
