@@ -4,7 +4,7 @@
  *
  * @package Knowledgeroot
  * @author Frank Habermann
- * @version $Id: class-email-notification.php 230 2006-11-19 12:52:59Z lordlamer $
+ * @version $Id: class-email-notification.php 517 2007-08-17 19:08:46Z lordlamer $
  */
 class knowledgeroot_notification extends PHPMailer {
 	var $CLASS = array();
@@ -19,11 +19,12 @@ class knowledgeroot_notification extends PHPMailer {
 
 	/**
 	 * add content to htmlheader for the noftificationmail
+	 * @param string $content
 	 */
 	function addMailHtmlHeader($content) {
 		$this->html_mail_header .= $content;
 	}
-	
+
 	/**
 	 * start mailnotification
 	 */
@@ -75,20 +76,52 @@ class knowledgeroot_notification extends PHPMailer {
 	/**
 	 * send email notification
 	 * id show the id of the modified element
+	 * @param integer $pageid id of page
+	 * @param string $elementType type of element
+	 * @param string $action action
+	 * @param string $name name of element
+	 * @param integer $id id of element
+	 * @param string $extratext some optional extra text
 	 */
 	function send_email_notification($pageid, $elementType, $action, $name = "", $id = "", $extratext = "") {
 		if($this->CLASS['vars']['email']['notification'] == 1) {
 			// get pagetitle
 			$pageTitle = $this->CLASS['path']->getTreePageTitle($pageid);
 
+			// check custom format
+			if (T_($elementType.'_text') != $elementType.'_text'){
+				$fmt = T_($elementType.'_text');
+			} else {
+				$fmt = '#elementType# "#name#" #was# #action#';
+			}
+			$subject_str = $fmt;
+			$subject_str = str_replace('#elementType#', T_($elementType), $subject_str);
+			$subject_str = str_replace('#name#', $name, $subject_str);
+			$subject_str = str_replace('#was#', T_('was'), $subject_str);
+			$subject_str = str_replace('#action#', T_($action), $subject_str);
+
 			// set emailsubject
-			$this->Subject = $this->CLASS['language']->sys['email']['notification'] . ' (' . $this->CLASS['language']->sys['email'][$elementType] . ' "' . $name . '" ' . $this->CLASS['language']->sys['email'][$action] . ')';
+			$this->Subject = T_('Knowledgeroot notification') . ' (' . $subject_str . ')';
 
 			// make html mail or not
 			if($this->html == true) {
 				// get path
 				$path = $this->CLASS['path']->getPath($pageid, $this->CLASS['kr_header']->get_base_url());
 
+				// check custom format
+			    if (T_($elementType.'_html') != $elementType.'_html'){
+				    $fmt = T_($elementType.'_html');
+			    } elseif (T_($elementType.'_text') != $elementType.'_text'){
+					$fmt = T_($elementType.'_text');
+				} else {
+					$fmt = '#elementType# "#name#" #was# <strong>#action#</strong>';
+				}
+				$action_str = $fmt;
+				$action_str = str_replace('#elementType#', T_($elementType), $action_str);
+				$action_str = str_replace('#name#', $name, $action_str);
+				$action_str = str_replace('#was#', T_('was'), $action_str);
+				$action_str = str_replace('#action#', T_($action), $action_str);
+
 				$mailBody = '
 <html>
 	<head><meta http-equiv="content-type" content="text/html; " /><style type="text/css"><!--
@@ -100,15 +133,15 @@ class knowledgeroot_notification extends PHPMailer {
 #msg dl a:hover  { color:#ff0; }
 		--></style>
 		'. $this->html_mail_header .'
-		<title>' . $this->CLASS['language']->sys['email']['notification'] . '</title>
+		<title>' . T_('Knowledgeroot notification') . '</title>
 	</head>
 	<body>
 		<div id="msg">
 		<dl>
-		<dt>' . $this->CLASS['language']->sys['path'] . '</dt> <dd>' . $path . '</dd>
-		<dt>' . $this->CLASS['language']->sys['email']['action'] . '</dt> <dd> ' . $this->CLASS['language']->sys['email'][$elementType] . ' "' . $name . '" ' . $this->CLASS['language']->sys['email']['was'] . ' <strong>' . $this->CLASS['language']->sys['email'][$action] . '</strong>' . ($id != "" ? " (ID: " . $id . ")<br />\n" : "") . '</dd>
-		<dt>' . $this->CLASS['language']->sys['email']['author'] . '</dt> <dd>' . $_SESSION['user'] . '</dd>
-		<dt>' . $this->CLASS['language']->sys['email']['date'] . '</dt> <dd>' . date("D, j M Y H:i:s") . '</dd>
+		<dt>' . T_('Path') . '</dt> <dd>' . $path . '</dd>
+		<dt>' . T_('Action') . '</dt> <dd> ' . $action_str . ($id != "" ? " (ID: " . $id . ")<br />\n" : "") . '</dd>
+		<dt>' . T_('author') . '</dt> <dd>' . $_SESSION['user'] . '</dd>
+		<dt>' . T_('date') . '</dt> <dd>' . date("D, j M Y H:i:s") . '</dd>
 		</dl>
 		</div>';
 
@@ -124,13 +157,13 @@ class knowledgeroot_notification extends PHPMailer {
 				// get path
 				$path = $this->CLASS['path']->getTextPath($pageid, $this->CLASS['kr_header']->get_base_url());
 
-				$mailBody = $this->CLASS['language']->sys['path'] . ': ' . $path."\n";
-				$mailBody .= 'Action: ' . $this->CLASS['language']->sys['email'][$elementType] . ' ' .$this->CLASS['language']->sys['email'][$action] . ($id != "" ? " (ID: " . $id . ")\n" : "\n");
-				$mailBody .= 'Author: ' . $_SESSION['user']."\n";
-				$mailBody .= 'Date: ' . date("D, j M Y H:i:s")."\n";
+				$mailBody = T_('Path') . ': ' . $path."\n";
+				$mailBody .= T_('Action') . ': ' . $subject_str . ($id != "" ? " (ID: " . $id . ")\n" : "\n");
+				$mailBody .= T_('Author'). ': ' . $_SESSION['user']."\n";
+				$mailBody .= T_('Date') . ': ' . date("D, j M Y H:i:s")."\n";
 
 				if ($extratext != "") {
-					$mailBody .= "\nDetail of Changes: \n\n" . $extratext . "\n";
+					$mailBody .= "\n" . T_('Detail of Changes') . ": \n\n" . $extratext . "\n";
 				}
 			}
 
@@ -139,7 +172,7 @@ class knowledgeroot_notification extends PHPMailer {
 
 			// send email
 			if (!$this->Send()) {
-				$this->CLASS['kr_header']->addwarning($this->CLASS['language']->sys['email']['errormessage'] . ': ' . $this->ErrorInfo);
+				$this->CLASS['kr_header']->addwarning(T_('Unable to send email notification') . ': ' . $this->ErrorInfo);
 			}
 
 			// do some cleanup
@@ -148,4 +181,4 @@ class knowledgeroot_notification extends PHPMailer {
 		}
 	}
 }
-?>
\ No newline at end of file
+?>
