@@ -4,7 +4,7 @@
  *
  * @package Knowledgeroot
  * @author Frank Habermann
- * @version $Id: class-knowledgeroot-extension.php 352 2007-04-20 19:25:34Z lordlamer $
+ * @version $Id: class-knowledgeroot-extension.php 886 2009-10-30 22:32:45Z lordlamer $
  */
 class knowledgeroot_extension {
 	var $CLASS = array();
@@ -16,6 +16,8 @@ class knowledgeroot_extension {
 
 	/**
 	 * init/start class
+	 * @param array $CLASS
+	 * @param integer $adminext
 	 */
 	function start(&$CLASS, $adminext = 0) {
 		$this->CLASS =& $CLASS;
@@ -27,6 +29,7 @@ class knowledgeroot_extension {
 
 	/**
 	 * get list of extensions to load them
+	 * @param integer $adminext
 	 */
 	function loading_extensions($adminext = 0) {
 		if($adminext) {
@@ -37,21 +40,56 @@ class knowledgeroot_extension {
 
 		$res = $this->CLASS['db']->query($query);
 		while($row = $this->CLASS['db']->fetch_assoc($res)) {
-			$this->load_extension($row['keyname']);
+			// set default extension folder
+			$folder = "system/extension/";
+
+
+			$this->load_extension($row['keyname'], $this->checkExtensionFolder($row['keyname']));
 		}
 
 		return 0;
 	}
 
 	/**
-	 * load a extension to knowledgeroot
+	 * will check in which folder is extension located
+	 * @param string $extension keyname of extension
+	 * @return string relativ path of extension
 	 */
-	function load_extension($extension) {
+	function checkExtensionFolder($extension) {
+		$path = "";
+
+		/*
+		 * check folders in that order
+		 * 1. extension/
+		 * 2. system/extension/
+		 * 3. system/sysext/
+		 */
+		if(is_file($this->CLASS['vars']['base_path'] . "extension/" . $extension . "/info.php")) {
+			$path = "extension/";
+		} elseif(is_file($this->CLASS['vars']['base_path'] . "system/extension/" . $extension . "/info.php")) {
+			$path = "system/extension/";
+		} elseif(is_file($this->CLASS['vars']['base_path'] . "system/sysext/" . $extension . "/info.php")) {
+			$path = "system/sysext/";
+		} else {
+			$path = "extension/";
+		}
+
+		return $path;
+	}
+
+	/**
+	 * load a extension to knowledgeroot
+	 * @param string $extension name of extension
+	 * @param string $ext_folder folder of extension
+	 */
+	function load_extension($extension, $ext_folder = "") {
 		if (!isset ($this->CLASS['extension'][$extension]['init']) or $this->CLASS['extension'][$extension]['init'] != TRUE) {
-			$classfile = $this->CLASS['vars']['base_path'] . "/system/extension/" . $extension . "/class-" . $extension . ".php";
-			$infofile = $this->CLASS['vars']['base_path'] . "/system/extension/" . $extension . "/info.php";
-			$langfile = $this->CLASS['vars']['base_path'] . "/system/extension/" . $extension . "/language.php";
-			$configfile = $this->CLASS['vars']['base_path'] . "/system/extension/" . $extension . "/config.php";
+			$classname = $extension;
+			$classfile = $this->CLASS['vars']['base_path'] . $ext_folder . $extension . "/class-" . $extension . ".php";
+			$infofile = $this->CLASS['vars']['base_path'] . $ext_folder . $extension . "/info.php";
+			$langfile = $this->CLASS['vars']['base_path'] . $ext_folder . $extension . "/language.php";
+			$configfile = $this->CLASS['vars']['base_path'] . $ext_folder . $extension . "/config.php";
+			$langfolder = $this->CLASS['vars']['base_path'] . $ext_folder . $extension . "/language";
 
 			if(is_file($infofile)) {
 				$CONF = array();
@@ -60,6 +98,18 @@ class knowledgeroot_extension {
 				$this->CLASS['extension'][$extension]['info'] = $CONF;
 				unset($CONF);
 
+				// check for different classname
+				if(isset($this->CLASS['extension'][$extension]['info']['classname']) && $this->CLASS['extension'][$extension]['info']['classname'] != '')
+				{
+						$classname = $this->CLASS['extension'][$extension]['info']['classname'];
+				}
+
+				// check for different classfile
+				if(isset($this->CLASS['extension'][$extension]['info']['classfile']) && $this->CLASS['extension'][$extension]['info']['classfile'] != '')
+				{
+						$classfile = $this->CLASS['vars']['base_path'] . $ext_folder . $extension . "/" . $this->CLASS['extension'][$extension]['info']['classfile'];
+				}
+
 				// check for dependencies
 				if($this->CLASS['extension'][$extension]['info']['dependencies'] != "") {
 					$ext_list = explode(",",$this->CLASS['extension'][$extension]['info']['dependencies']);
@@ -69,7 +119,7 @@ class knowledgeroot_extension {
 					}
 
 					foreach($ext_list as $ext_key => $ext_val) {
-						if($this->CLASS['extension'][$ext_val]['init'] != TRUE) {
+						if((!isset($this->CLASS['extension'][$ext_val]['init'])) || (isset($this->CLASS['extension'][$ext_val]['init']) && $this->CLASS['extension'][$ext_val]['init'] != TRUE)) {
 							// load dependend extension
 							if(!$this->load_extension($ext_val)) {
 								return 0;
@@ -79,20 +129,14 @@ class knowledgeroot_extension {
 				}
 			}
 
-			if(is_file($langfile)) {
-				$LANG = array();
-				include($langfile);
-
-				$this->CLASS['language']->load_ext_lang($extension, $LANG);
-				unset($LANG);
-			}
-
 			if(is_file($classfile)) {
 				include($classfile);
 
 				$this->CLASS['extension'][$extension]['class_file'] = $classfile;
 				$this->CLASS['extension'][$extension]['init'] = TRUE;
-				$this->CLASS['extension'][$extension]['class'] = new $extension($this->CLASS);
+				$this->CLASS['extension'][$extension]['class'] = new $classname($this->CLASS);
+				$this->CLASS['extension'][$extension]['class']->myPath = $ext_folder . $extension . "/";
+				$this->CLASS['extension'][$extension]['class']->myAbsolutePath = $this->CLASS['vars']['base_path'] . $ext_folder . $extension . "/";
 
 				if(is_file($configfile)) {
 					include($configfile);
@@ -108,6 +152,24 @@ class knowledgeroot_extension {
 					unset($CONF);
 				}
 
+				// load gettext langfiles if directory exists
+				if (@is_dir ($langfolder)) {
+					//$this->CLASS['error']->DebugOut(DEFAULT_LOCALE);
+					T_bindtextdomain($extension, $langfolder);
+				} else {
+					// ToDo: Von hier aus koennte eine interne Fehlermeldung in eine Logdatei geschrieben
+					// werden (wenn diese Funktion einmal zur Verfuegung steht).
+				}
+
+				// load language from language.php
+				if(is_file($langfile)) {
+					$LANG = array();
+					include($langfile);
+
+					$this->CLASS['language']->load_ext_lang($extension, $LANG);
+					unset($LANG);
+				}
+
 				return 1;
 			}
 
@@ -121,7 +183,7 @@ class knowledgeroot_extension {
 	function start_extensions() {
 		if (isset ($this->CLASS['extension']) and is_array($this->CLASS['extension'])) {
 			foreach($this->CLASS['extension'] as $key => $value) {
-				if($this->CLASS['extension'][$key]['init'] == TRUE) {
+				if(isset($this->CLASS['extension'][$key]['init']) && $this->CLASS['extension'][$key]['init'] == TRUE) {
 					$content = $this->CLASS['extension'][$key]['class']->main();
 
 					if($content != "0" && $content != "1" && $content != "") {
@@ -141,7 +203,7 @@ class knowledgeroot_extension {
 	function load_menus() {
 		if (isset ($this->CLASS['extension']) and is_array($this->CLASS['extension'])) {
 			foreach($this->CLASS['extension'] as $key => $value) {
-				if($this->CLASS['extension'][$key]['init'] == TRUE) {
+				if(isset($this->CLASS['extension'][$key]['init']) && $this->CLASS['extension'][$key]['init'] == TRUE) {
 					$this->menu = array_merge_recursive($this->menu, $this->CLASS['extension'][$key]['class']->menu);
 				}
 			}
@@ -149,9 +211,17 @@ class knowledgeroot_extension {
 	}
 
 	/**
-	 * show top menu
+	 * Create a menu
+	 *
+	 * @param string $name name of menu
+	 * @param integer $id id of page
+	 * @param integer $pagerights rights of the page
+	 * @param integer $contentrights rights of the content
+	 * @param string $extension name of extension
+	 * @return string return menu as html
 	 */
-	function show_menu($name,$id = "", $pagerights = "", $contentrights = "",$extension = "") {
+	function show_menu($name,$id = "", $pagerights = null, $contentrights = null,$extension = "") {
+		$out = "";
 		$menuarr = array();
 
 		if(!isset($this->menu[$name])) $this->menu[$name] = array();
@@ -161,8 +231,13 @@ class knowledgeroot_extension {
 		}
 
 		foreach($this->menu[$name] as $key => $value) {
+			// check for config - config is no real menu
+			if($key == "config") {
+				continue;
+			}
+
 			// check for extension to display the navi
-			if($name == "content" || $name == "contentline") {
+			if($name == "content" || $name == "contentline" || $name == "contentcontext") {
 				$show = 0;
 
 				if (isset($this->menu[$name][$key]['contenttype'])) {
@@ -236,7 +311,7 @@ class knowledgeroot_extension {
 
 			// make image link or normal link
 			if (isset ($this->menu[$name][$key]['image']) and $this->menu[$name][$key]['image'] != "") {
-				$link = "<a href=\"" . $href . "\"" . $target . $title . $atagparams . "><img src=\"" . $this->menu[$name][$key]['image'] . "\" border=\"0\"" . $imagewidth . $imageheight . $title . " /></a>";
+				$link = "<a href=\"" . $href . "\"" . $target . $title . $atagparams . "><img src=\"" . $this->menu[$name][$key]['image'] . "\" border=\"0\"" . $imagewidth . $imageheight . $title . " alt=\"". $this->menu[$name][$key]['name'] ."\"/></a>";
 			} else {
 				$link = "<a href=\"" . $href . "\"" . $target . $title . $atagparams . ">" . $this->menu[$name][$key]['name'] . "</a>";
 			}
@@ -244,17 +319,21 @@ class knowledgeroot_extension {
 			// check for toolbar of for image
 			if ($name != "toolbar" &&
 				  (!isset ($this->menu[$name][$key]['image']) or $this->menu[$name][$key]['image'] == "") &&
-				  (!isset ($this->menu[$name][$key]['wrap']) or $this->menu[$name][$key]['wrap'] == "")) {
+				  (!isset ($this->menu[$name][$key]['wrap']) or $this->menu[$name][$key]['wrap'] == "") &&
+				  (!isset ($this->menu[$name]['config']['defaultelementwrap']) or $this->menu[$name]['config']['defaultelementwrap'] == "")) {
 				$link = "[" . $link . "]";
 			}
 
 			// set wrap
 			if (isset ($this->menu[$name][$key]['wrap']) and $this->menu[$name][$key]['wrap'] != "") {
 				$link = $this->CLASS['knowledgeroot']->setWrap($link,$this->menu[$name][$key]['wrap']);
+			} elseif(isset ($this->menu[$name]['config']['defaultelementwrap']) and $this->menu[$name]['config']['defaultelementwrap'] != "") {
+				$link = $this->CLASS['knowledgeroot']->setWrap($link,$this->menu[$name]['config']['defaultelementwrap']);
 			}
 
 			// check for dynamic vars and replace them
 			$link = str_replace('{$ID}', $id, $link);
+			if(isset($_SESSION['cid'])) $link = str_replace('{$PAGEID}', $_SESSION['cid'], $link);
 
 			// check for adminrights
 			if ((!isset ($_SESSION['admin']) or $_SESSION['admin'] != "1") &&
@@ -264,13 +343,13 @@ class knowledgeroot_extension {
 			}
 
 			// check pagerights
-			if ($pagerights != "" && isset ($this->menu[$name][$key]['pagerights']) and $pagerights < $this->menu[$name][$key]['pagerights']) {
+			if ($pagerights != null && isset ($this->menu[$name][$key]['pagerights']) and $pagerights < $this->menu[$name][$key]['pagerights']) {
 				// do not display item
 				continue;
 			}
 
 			// check contenrights
-			if ($contentrights != "" && isset ($this->menu[$name][$key]['contentrights']) and $contentrights < $this->menu[$name][$key]['contentrights']) {
+			if ($contentrights != null && isset ($this->menu[$name][$key]['contentrights']) and $contentrights < $this->menu[$name][$key]['contentrights']) {
 				// do not display item
 				continue;
 			}
@@ -303,12 +382,27 @@ class knowledgeroot_extension {
 
 		// display menu
 		foreach($menuarr as $key => $value) {
-			echo $menuarr[$key]['link'];
+			$out .= $menuarr[$key]['link'];
 		}
+
+		// check for wrap in this menu
+		if(isset($this->menu[$name]['config']['wrap']) && $this->menu[$name]['config']['wrap'] != "") {
+			if(isset($this->menu[$name]['config']['admin']) && $this->menu[$name]['config']['admin'] == "1") {
+				if(isset($_SESSION['admin']) && $_SESSION['admin'] == 1) {
+					$out = $this->CLASS['knowledgeroot']->setWrap($out,$this->menu[$name]['config']['wrap']);
+				}
+			} else {
+				$out = $this->CLASS['knowledgeroot']->setWrap($out,$this->menu[$name]['config']['wrap']);
+			}
+		}
+
+		return $out;
 	}
 
 	/**
-	 * show admin menu
+	 * Create admin menu
+	 * @param string $name name of menu
+	 * @param integer $parent
 	 */
 	function show_admin_menu($name, $parent = "") {
 		$menuarr = array();
@@ -320,6 +414,11 @@ class knowledgeroot_extension {
 		$count_items = 0;
 
 		foreach($this->menu[$name] as $key => $value) {
+			// check for config - config is no real menu
+			if($key == "config") {
+				continue;
+			}
+
 			if($parent != "") {
 				if (!isset ($this->menu[$name][$key]['parent']) or $this->menu[$name][$key]['parent'] != $parent) {
 					continue;
@@ -407,6 +506,9 @@ class knowledgeroot_extension {
 
 	/**
 	 * return an array with all files and folders from a directory
+	 * @param string $path
+	 * @param string $filepath
+	 * @return array
 	 */
 	function getFileArr($path, $filepath = "") {
 		if($filepath != "" && substr($filepath,-1,1) != "/") {
@@ -417,7 +519,7 @@ class knowledgeroot_extension {
 
 		$handle = opendir($path);
 		while (false !== ($file = readdir($handle))) {
-			if ($file != "." && $file != "..") {
+			if ($file != "." && $file != ".." && $file != ".svn" && $file != "CVS") {
 				if(is_dir($path."/".$file)) {
 					$fileArr[$file]['type'] = "dir";
 					$fileArr[$file]['content'] = $this->getFileArr($path."/".$file,$file);
@@ -436,6 +538,8 @@ class knowledgeroot_extension {
 
 	/**
 	 * return content of a file
+	 * @param string $file
+	 * @return string
 	 */
 	function getFileContent($file) {
 		$content = "";
@@ -454,6 +558,9 @@ class knowledgeroot_extension {
 
 	/**
 	 * return a full extension as string
+	 * @param string $keyname
+	 * @param string $path
+	 * @return string
 	 */
 	function makeExtension($keyname, $path) {
 		//print_r(gzcompress(base64_encode(serialize($this->getFileArr("/www/projekte/knowledgeroot/system/extension/livediagram/")))));
@@ -487,6 +594,7 @@ class knowledgeroot_extension {
 	/**
 	 * fetch extension from repository
 	 * url is url to extension repository
+	 * @param string $url
 	 */
 	function fetchExtension($url) {
 
@@ -494,6 +602,8 @@ class knowledgeroot_extension {
 
 	/**
 	 * return filearray from a extensionfilecontent
+	 * @param string $content
+	 * @return array
 	 */
 	function getExtensionData($content) {
 		$parts = explode(":", $content);
@@ -501,7 +611,7 @@ class knowledgeroot_extension {
 		$method = $parts[1];
 
 		$fileArr = array();
-		
+
 		if($method == "gzcompress") {
 			if(function_exists('gzuncompress')) {
 				$data = gzuncompress(base64_decode($parts[2]));
@@ -523,6 +633,9 @@ class knowledgeroot_extension {
 
 	/**
 	 * write content to a file
+	 * @param string $file
+	 * @param string $content
+	 * @return bool
 	 */
 	function putFileContent($file,$content="") {
 		//echo "$file\n";
@@ -538,6 +651,8 @@ class knowledgeroot_extension {
 
 	/**
 	 * save a extension to a path
+	 * @param array $extArr
+	 * @param string $path
 	 */
 	function saveExtension($extArr,$path) {
 		$this->createExtFolders($extArr,$path);
@@ -546,6 +661,8 @@ class knowledgeroot_extension {
 
 	/**
 	 * create files from a extension array to a path
+	 * @param array $extArr
+	 * @param string $path
 	 */
 	function createExtFiles($extArr,$path) {
 		if(substr($path,-1,1) != "/") {
@@ -563,6 +680,8 @@ class knowledgeroot_extension {
 
 	/**
 	 * create folders from a extension array to a path
+	 * @param array $extArr
+	 * @param string $path
 	 */
 	function createExtFolders($extArr, $path) {
 		if(substr($path,-1,1) != "/") {
@@ -582,6 +701,9 @@ class knowledgeroot_extension {
 
 	/**
 	 * create folders recursiv
+	 * @param string $dirname
+	 * @param integer $rights
+	 * @return bool
 	 */
 	function mkdir_r($dirName, $rights=0777){
 		$dirs = explode('/', $dirName);
@@ -592,7 +714,7 @@ class knowledgeroot_extension {
 			if (!@is_dir($dir) && strlen($dir)>1)
 				@mkdir($dir, $rights);
 		}
-		
+
 		// check if folder was created
 		if(@is_dir($dirName)) {
 			return true;
@@ -603,6 +725,7 @@ class knowledgeroot_extension {
 
 	/**
 	 * enable a extension
+	 * @param string $keyname
 	 */
 	function enableExtension($keyname) {
 		$res = $this->CLASS['db']->query(sprintf("UPDATE extensions SET active=1 WHERE keyname='%s'",$keyname));
@@ -610,6 +733,7 @@ class knowledgeroot_extension {
 
 	/**
 	 * disable a extension
+	 * @param string $keyname
 	 */
 	function disableExtension($keyname) {
 		$res = $this->CLASS['db']->query(sprintf("UPDATE extensions SET active=0 WHERE keyname='%s'",$keyname));
@@ -619,6 +743,8 @@ class knowledgeroot_extension {
 	/**
 	 * install a extension in database table
 	 * not on disk
+	 * @param string $keyname
+	 * @param integer $admin
 	 */
 	function installExtension($keyname, $admin = 0) {
 		$res = $this->CLASS['db']->query(sprintf("SELECT id FROM extensions WHERE keyname='%s'",$keyname));
