@@ -4,19 +4,19 @@
  *
  * @package Knowledgeroot
  * @author Frank Habermann
- * @version $Id: class-knowledgeroot-themes.php 281 2007-01-28 21:03:07Z lordlamer $
+ * @version $Id: class-knowledgeroot-themes.php 453 2007-06-03 19:17:10Z lordlamer $
  */
 class knowledgeroot_themes {
 	var $CLASS;
 	var $theme = array();
-	var $default_theme = "default";
+	var $default_theme = "green";
 	var $use_theme = "";
 	var $theme_folder = "system/themes/";
 
 	/**
 	 * init/start class
 	 */
-	function start(&$CLASS,$theme = "") {
+	function start(&$CLASS) {
 		$this->CLASS =& $CLASS;
 		
 		if(isset($this->CLASS['vars']['include_prefix']) && $this->CLASS['vars']['include_prefix'] != "") {
@@ -25,8 +25,8 @@ class knowledgeroot_themes {
 		
 		$this->search_themes();
 
-		if($theme != "") {
-			$this->use_theme = $theme;
+		if(isset($this->CLASS['vars']['knowledgeroot']['default_theme'])) {
+			$this->use_theme = $this->CLASS['vars']['knowledgeroot']['default_theme'];
 		}
 	}
 
@@ -51,6 +51,15 @@ class knowledgeroot_themes {
 		}
 	}
 
+	/**
+	 * load a theme to internal theme array
+	 */
+	function load_ext_theme($themeArr) {
+		if($themeArr['name'] != "") {
+			$this->themes[$themeArr['name']] = $themeArr;
+		}
+	}
+
 	/**
 	 * return path to css_file
 	 */
@@ -59,8 +68,17 @@ class knowledgeroot_themes {
 			$this->use_theme = $_SESSION['theme'];
 		}
 
-		$default_css_file = $this->theme_folder . $this->default_theme . "/" . $this->themes[$this->default_theme]['css_file'];
-		$use_css_file = $this->theme_folder . $this->use_theme . "/" . $this->themes[$this->use_theme]['css_file'];
+		if(isset($this->themes[$this->default_theme]['path']) && is_file($this->themes[$this->default_theme]['path']."/".$this->themes[$this->default_theme]['css_file'])) {
+			$default_css_file = $this->themes[$this->default_theme]['path']."/".$this->themes[$this->default_theme]['css_file'];
+		} else {
+			$default_css_file = $this->theme_folder . $this->default_theme . "/" . $this->themes[$this->default_theme]['css_file'];
+		}
+
+		if(isset($this->themes[$this->use_theme]['path']) && is_file($this->themes[$this->use_theme]['path']."/".$this->themes[$this->use_theme]['css_file'])) {
+			$use_css_file = $this->themes[$this->use_theme]['path']."/".$this->themes[$this->use_theme]['css_file'];
+		} else {
+			$use_css_file = $this->theme_folder . $this->use_theme . "/" . $this->themes[$this->use_theme]['css_file'];
+		}
 
 		if(is_file($use_css_file)) {
 			$css = $use_css_file;
