@@ -4,7 +4,7 @@
  *
  * @package Knowledgeroot
  * @author Frank Habermann
- * @version $Id: class-tree.php 356 2007-04-22 13:02:35Z lordlamer $
+ * @version $Id: class-tree.php 679 2009-04-02 22:24:00Z lordlamer $
  */
 class pathTree {
   var $CLASS;
@@ -146,7 +146,7 @@ class pathTree {
  *
  * @package Knowledgeroot
  * @author Frank Habermann
- * @version $Id: class-tree.php 356 2007-04-22 13:02:35Z lordlamer $
+ * @version $Id: class-tree.php 679 2009-04-02 22:24:00Z lordlamer $
  */
 class categoryTree {
   var $out = array(); // elemts for the user
@@ -203,52 +203,51 @@ class categoryTree {
       return $this->category;
     }
 
+    // get order by
+    if(isset($this->CLASS['vars']['menu']['order']['self']) && $this->CLASS['vars']['menu']['order']['self'] == 1) {
+      $orderby = "sorting";
+    } else {
+      $orderby = "title";
+    }
+
     //fr mysql umschreiben
-    if($this->admin == 1) {
-      $query = "SELECT * FROM tree WHERE deleted=0 ORDER BY title ASC";
+    //if($this->admin == 1) {
+    // enable all because of multiple rights
+    if(1) {
+      $query = sprintf("SELECT * FROM tree WHERE deleted=0 ORDER BY %s ASC", $orderby);
     } else {
-      if($this->CLASS['db']->dbtype == "mysql" || $this->CLASS['db']->dbtype == "mysqli") {
         if($_SESSION['groupid'] == 0) {
-          $query = sprintf("SELECT * FROM tree WHERE deleted=0 AND ((otherrights > 0) OR (`group`=%d AND grouprights > 0) OR (owner=%d AND userrights>0)) ORDER BY title ASC",$_SESSION['groupid'],$_SESSION['userid']);
+          $query = sprintf("SELECT * FROM tree WHERE deleted=0 AND ((otherrights > 0) OR (".$this->CLASS['db']->quoteIdentifier("group")."=%d AND grouprights > 0) OR (owner=%d AND userrights>0)) ORDER BY %s ASC",$_SESSION['groupid'],$_SESSION['userid'],$orderby);
         } else {
-          $query_part = sprintf(" OR (`group`=%d AND grouprights > 0)",$_SESSION['groupid']);
+          $query_part = sprintf(" OR (".$this->CLASS['db']->quoteIdentifier("group")."=%d AND grouprights > 0)",$_SESSION['groupid']);
 
           $res = $this->CLASS['db']->query(sprintf("SELECT groupid FROM user_group WHERE userid=%d",$_SESSION['userid']));
           while($row = $this->CLASS['db']->fetch_assoc($res)) {
-            $query_part .= sprintf(" OR (`group`=%d AND grouprights > 0)",$row['groupid']);
+            $query_part .= sprintf(" OR (".$this->CLASS['db']->quoteIdentifier("group")."=%d AND grouprights > 0)",$row['groupid']);
           }
 
-          $query = sprintf("SELECT * FROM tree WHERE deleted=0 AND ((otherrights > 0) %s OR (owner=%d AND userrights>0)) ORDER BY title ASC",$query_part,$_SESSION['userid']);
+          $query = sprintf("SELECT * FROM tree WHERE deleted=0 AND ((otherrights > 0) %s OR (owner=%d AND userrights>0)) ORDER BY %s ASC",$query_part,$_SESSION['userid'],$orderby);
         }
-      } else {
-        if($_SESSION['groupid'] == 0) {
-          $query = sprintf("SELECT * FROM tree WHERE deleted=0 AND ((otherrights > 0) OR (\"group\"=%d AND grouprights > 0) OR (owner=%d AND userrights>0)) ORDER BY title ASC",$_SESSION['groupid'],$_SESSION['userid']);
-        } else {
-          $query_part = sprintf(" OR (\"group\"=%d AND grouprights > 0)",$_SESSION['groupid']);
-
-          $res = $this->CLASS['db']->query(sprintf("SELECT groupid FROM user_group WHERE userid=%d",$_SESSION['userid']));
-          while($row = $this->CLASS['db']->fetch_assoc($res)) {
-            $query_part .= sprintf(" OR (\"group\"=%d AND grouprights > 0)",$row['groupid']);
-          }
-
-          $query = sprintf("SELECT * FROM tree WHERE deleted=0 AND ((otherrights > 0) %s OR (owner=%d AND userrights>0)) ORDER BY title ASC",$query_part,$_SESSION['userid']);
-        }
-      }
     }
 
     $res = $this->CLASS['db']->query($query);
 
     while ( $var = $this->CLASS['db']->fetch_assoc($res) ) {
+		if($this->CLASS['knowledgeroot']->checkRecursivPerm($var['id'],$_SESSION['userid']) > 0) {
       $out[ $var['belongs_to'] ][ $var['id'] ]['title'] = $var['title'];
+      $out[ $var['belongs_to'] ][ $var['id'] ]['tooltip'] = $var['tooltip'];
       $out[ $var['belongs_to'] ][ $var['id'] ]['alias'] = $var['alias'];
       $out[ $var['belongs_to'] ][ $var['id'] ]['id'] = $var['id'];
       $out[ $var['belongs_to'] ][ $var['id'] ]['belongs_to'] = $var['belongs_to'];
-      $myout[ $var['id'] ] = $var['belongs_to'];
+      $out[ $var['belongs_to'] ][ $var['id'] ]['symlink'] = $var['symlink'];
+      $myout[ $var['id'] ]['id'] = $var['belongs_to'];
+      $myout[ $var['id'] ]['symlink'] = $var['symlink'];
 
       if($this->firstrun == 1) {
         $this->open[$var['id'] ] = 0;
         $_SESSION['open'][$var['id']] = 0;
       }
+		}
     }
 
     $this->out = &$out;
@@ -261,7 +260,14 @@ class categoryTree {
    *
    */
   function readAllCategories() {
-    $query = "SELECT * FROM tree WHERE deleted=0 ORDER BY title ASC";
+    // get order by
+    if(isset($this->CLASS['vars']['menu']['order']['self']) && $this->CLASS['vars']['menu']['order']['self'] == 1) {
+      $orderby = "sorting";
+    } else {
+      $orderby = "title";
+    }
+
+    $query = sprintf("SELECT * FROM tree WHERE deleted=0 ORDER BY %s ASC",$orderby);
     $res = $this->CLASS['db']->query($query);
 
     while ( $var = $this->CLASS['db']->fetch_assoc($res) ) {
@@ -320,7 +326,7 @@ class categoryTree {
         ';
 
       // show tree menu
-      $this->CLASS['kr_extension']->show_menu("tree",$moveparam);
+      echo $this->CLASS['kr_extension']->show_menu("tree",$moveparam);
 
       echo '
               </tr>
@@ -342,6 +348,9 @@ class categoryTree {
     }
 
     echo "</table>\n";
+
+	// treebottom navi
+	echo $this->CLASS['kr_extension']->show_menu("treebottom");
   }
 
 	/**
@@ -353,7 +362,7 @@ class categoryTree {
 		} else {
 			$this->open = array();
 		}
-		
+
 		$cats = $this->readCategories();
 
 		if($id == "0") {
@@ -363,15 +372,15 @@ class categoryTree {
 		}
 
 		$spaces = $this->getDeepPart($id) + $depth;
-		
+
 		$out = "";
-		
+
 		if($this->editor == TRUE) {
 			$out .= $this->getContentTitleOfPage($id,$depth+1);
 		}
-		
+
 		$out .= $this->showAjaxTreePart( $this->getTreePart($id), $spaces );
-		
+
 		return $out;
 
 	}
@@ -403,12 +412,12 @@ class categoryTree {
 
           if($this->lastPart($id) == 0) {
             if ((isset ($_SESSION['open'][$id]) and $_SESSION['open'][$id] == 1) || $this->expand == 1 || $this->doexpand == 1) {
-              $spaces = $space . "&nbsp;<a class=\"image\" href=\"".$indexfile."?openid=$id\"><img border=\"0\" width=\"9\" height=\"9\" alt=\"\" src=\"images/minus.jpg\" /></a>&nbsp;";
+              $spaces = $space . "&nbsp;<a class=\"image\" href=\"".$indexfile."?openid=$id\"><img border=\"0\" alt=\"\" width=\"9\" height=\"9\" src=\"images/minus.jpg\" /></a>&nbsp;";
             } else {
-              $spaces = $space . "&nbsp;<a class=\"image\" href=\"".$indexfile."?openid=$id\"><img border=\"0\" width=\"9\" height=\"9\" alt=\"\" src=\"images/plus.jpg\" /></a>&nbsp;";
+              $spaces = $space . "&nbsp;<a class=\"image\" href=\"".$indexfile."?openid=$id\"><img border=\"0\" alt=\"\" width=\"9\" height=\"9\" src=\"images/plus.jpg\" /></a>&nbsp;";
             }
           } else {
-            $spaces = $space . "&nbsp;<img class=\"bullet\" width=\"7\" height=\"7\" alt=\"\" src=\"images/black.gif\" />&nbsp;";
+            $spaces = $space . "&nbsp;<img class=\"bullet\" alt=\"\" width=\"7\" height=\"7\" src=\"images/black.gif\" />&nbsp;";
           }
 
           // check if link a actual element
@@ -419,9 +428,9 @@ class categoryTree {
           }
 
           if($this->move == TRUE) {
-            $out .= "<tr><td class=\"tree\" nowrap=\"nowrap\">".$spaces . "<a ".$class_act."href=\"#\" onclick=\"window.opener.document.forms.move.to.value = '".$id."'; window.opener.document.forms.move.submit(); window.close();\">" . $title['title'] . "</a></td></tr>\n";
+            $out .= "<tr><td class=\"tree\" nowrap=\"nowrap\">".$spaces . ((isset($this->CLASS['vars']['menu']['showcounter']) && $this->CLASS['vars']['menu']['showcounter'] == 1) ? "<span class=\"treecounter\">" . $itemcounter . ".</span> " : "") . "<a ".$class_act."href=\"#\" onclick=\"window.opener.document.forms.move.to.value = '".$id."'; window.opener.document.forms.move.submit(); window.close();\">" . $title['title'] . "</a></td></tr>\n";
           } else {
-            $out .= "<tr><td class=\"tree\" nowrap=\"nowrap\">".$spaces . "<a ".$class_act."href=\"" . $this->makeLink($title) . "\">" . $title['title'] . "</a></td></tr>\n";
+            $out .= "<tr><td class=\"tree\" nowrap=\"nowrap\">".$spaces . ((isset($this->CLASS['vars']['menu']['showcounter']) && $this->CLASS['vars']['menu']['showcounter'] == 1) ? "<span class=\"treecounter\">" . $itemcounter . ".</span> " : "") . "<a ".$class_act."href=\"" . $this->makeLink($title) . "\">" . (($this->isSymlink($id) != 0) ? "#" : "") . $title['title'] . "</a></td></tr>\n";
           }
 
           if ((isset ($this->open[$id]) and $this->open[$id] == 1) || $this->expand == 1 || $this->doexpand == 1) {
@@ -446,27 +455,22 @@ class categoryTree {
 		$minusImage = "minus.jpg";
 		$plusImage = "plus.jpg";
 
-		// check if page is editor plugin page
-		if($this->editor == TRUE) {
-			if ($this->CLASS['vars']['htmleditor']['editor'] == "fckeditor") {
-				$imagePrefix = "../../../../";
-			} else {
-				$imagePrefix = "../../../../../../";
-			}
-		}
-		
+		$imagePrefix = $this->CLASS['knowledgeroot']->getEnv("REQUEST_DIR");
+
 		for ( $i=0; $i<$indent; $i++ ) {
 			$space .= "&nbsp;<img src=\"".$imagePrefix."images/clear.gif\" width=\"9\" height=\"9\" alt=\"\" />&nbsp;";
 		}
 
 		$out = "";
+		$itemcounter = 0;
 
 		if( count( $arr ) > 0 ) {
 			foreach( $arr as $id => $title ) {
+				$itemcounter++;
 				if($title == "") {
 					$title = "[EMPTY]";
 				}
-				
+
 				if($this->lastPart($id) == 0) {
 					$moveparam = "";
 
@@ -476,18 +480,18 @@ class categoryTree {
 					} else {
 						$moveparam = "0";
 					}
-					
+
 					$useeditor = "";
 					if($this->editor == TRUE) $useeditor = 1;
 					else $useeditor = 0;
 
 					if ((isset ($_SESSION['open'][$id]) and $_SESSION['open'][$id] == 1) || $this->expand == 1 || $this->doexpand == 1) {
-						$spaces = $space . "&nbsp;<a id=\"linkid_".$id."\" class=\"image\" href=\"javascript:;\" onclick=\"AjaxMenuClose(".$id.",".$moveparam.",'".$imagePrefix."',".$useeditor.");\"><img id=\"menuimg_".$id."\" border=\"0\" width=\"9\" height=\"9\" alt=\"\" src=\"".$imagePrefix."images/".$minusImage."\" /></a>&nbsp;";
+						$spaces = $space . "&nbsp;<a id=\"linkid_".$id."\" class=\"image\" href=\"javascript:;\" onclick=\"AjaxMenuClose(".$id.",".$moveparam.",'".$imagePrefix."',".$useeditor.");\"><img id=\"menuimg_".$id."\" border=\"0\" alt=\"\" width=\"9\" height=\"9\" src=\"".$imagePrefix."images/".$minusImage."\" /></a>&nbsp;";
 					} else {
-						$spaces = $space . "&nbsp;<a id=\"linkid_".$id."\" class=\"image\" href=\"javascript:;\" onclick=\"AjaxMenuOpen(".$id.",".$moveparam.",'".$imagePrefix."',".$useeditor.");\"><img id=\"menuimg_".$id."\" border=\"0\" width=\"9\" height=\"9\" alt=\"\" src=\"".$imagePrefix."images/".$plusImage."\" /></a>&nbsp;";
+						$spaces = $space . "&nbsp;<a id=\"linkid_".$id."\" class=\"image\" href=\"javascript:;\" onclick=\"AjaxMenuOpen(".$id.",".$moveparam.",'".$imagePrefix."',".$useeditor.");\"><img id=\"menuimg_".$id."\" border=\"0\" alt=\"\" width=\"9\" height=\"9\" src=\"".$imagePrefix."images/".$plusImage."\" /></a>&nbsp;";
 					}
 				} else {
-					$spaces = $space . "&nbsp;<img class=\"bullet\" width=\"7\" height=\"7\" alt=\"\" src=\"".$imagePrefix."images/black.gif\" />&nbsp;";
+					$spaces = $space . "&nbsp;<img class=\"bullet\" alt=\"\" width=\"7\" height=\"7\" src=\"".$imagePrefix."images/black.gif\" />&nbsp;";
 				}
 
 				// check if link a actual element
@@ -509,19 +513,48 @@ class categoryTree {
 					$class_root_item = "class=\"tree\"";
 				}
 
-				if($this->move == TRUE) {
-					$out .= "<tr id=\"menu_".$id."\"><td ".$class_root_item." nowrap=\"nowrap\">".$spaces . "<a ".$class_act."id=\"alink_".$id."\" href=\"#\" onclick=\"window.opener.document.forms.move.to.value = '".$id."'; window.opener.document.forms.move.submit(); window.close();\">" . $title['title'] . "</a></td></tr>\n";
-				} else if ($this->editor == TRUE) {
-					$out .= "<tr id=\"menu_".$id."\"><td ".$class_root_item." nowrap=\"nowrap\">".$spaces . "<a ".$class_act."id=\"alink_".$id."\" onclick=\"editorSelect('index.php?id=".$id."','".$title['title']."')\" href=\"#\">" .$title['title'] . "</a></td></tr>\n";
+				$mousecontext = "";
+
+				// check if contextmenu are enabled
+				if($this->CLASS['vars']['menu']['context'] == 1) {
+					// set mousecontext for rightclick menu
+					$mousecontext = " oncontextmenu=\"KnowledgerootMenu.show('mousemenu','pagecontext', ".$id."); return false;\"";
+				}
+
+				// set tooltip
+				if($this->CLASS['vars']['menu']['edittooltiptext'] == 1 && $title['tooltip'] != "") {
+					$tooltip = " title=\"".$title['tooltip']."\"";
 				} else {
-					$out .= "<tr id=\"menu_".$id."\"><td ".$class_root_item." nowrap=\"nowrap\">".$spaces . "<a ".$class_act."id=\"alink_".$id."\" href=\"" . $this->makeLink($title) . "\">" .$title['title'] . "</a></td></tr>\n";
+					$tooltip = " title=\"".$title['title']."\"";
+				}
+
+				if($this->move == TRUE) {
+					$out .= "<tr id=\"menu_".$id."\"><td ".$class_root_item." nowrap=\"nowrap\">".$spaces . ((isset($this->CLASS['vars']['menu']['showcounter']) && $this->CLASS['vars']['menu']['showcounter'] == 1) ? "<span class=\"treecounter\">" . $itemcounter . ".</span> " : "") . "<a ".$class_act."id=\"alink_".$id."\" href=\"#\" onclick=\"window.opener.document.forms.move.to.value = '".$id."'; window.opener.document.forms.move.submit(); window.close();\">" . $title['title'] . "</a></td></tr>\n";
+				} else if ($this->editor == TRUE) {
+					$out .= "<tr id=\"menu_".$id."\"><td ".$class_root_item." nowrap=\"nowrap\">".$spaces . ((isset($this->CLASS['vars']['menu']['showcounter']) && $this->CLASS['vars']['menu']['showcounter'] == 1) ? "<span class=\"treecounter\">" . $itemcounter . ".</span> " : "") . "<a ".$class_act."id=\"alink_".$id."\" onclick=\"editorSelect('index.php?id=".$id."','".$title['title']."')\" href=\"#\">" .$title['title'] . "</a></td></tr>\n";
+				} else {
+					$out .= "<tr id=\"menu_".$id."\"><td ".$class_root_item." nowrap=\"nowrap\">".$spaces . ((isset($this->CLASS['vars']['menu']['showcounter']) && $this->CLASS['vars']['menu']['showcounter'] == 1) ? "<span class=\"treecounter\">" . $itemcounter . ".</span> " : "") . "<a ".$class_act."id=\"alink_".$id."\" href=\"" . $this->makeLink($title) . "\"" . $mousecontext . $tooltip . ">" . (($this->isSymlink($id) != 0) ? "#" : "") .$title['title'] . "</a></td></tr>\n";
+				}
+
+				// check if drag and drop is enabled
+				if($this->CLASS['vars']['menu']['dragdrop'] == "1" && $this->move != TRUE && $this->editor != TRUE) {
+					// add javascript for drag and drop
+					$out .= '<script type="text/javascript" language="javascript">';
+					$out .= 'var navig_agt=navigator.userAgent.toLowerCase();
+var navig_ie=((navig_agt.indexOf("msie")!=-1) && (navig_agt.indexOf("opera")==-1));
+var navig_ie8=(navig_ie && (navig_agt.indexOf("msie 8.")!=-1));';
+					$out .= 'if((navigator.appName.toLowerCase() != "opera" && !document.all) || navig_ie8) {';
+					$out .= "new Draggable('menu_".$id."', {handle: 'alink_".$id."', revert:true, ghosting: false, zindex: 900, starteffect:function() { Dragbox.show(\$('alink_'+".$id.").innerHTML); }, endeffect:function() { Dragbox.hide(); }  });";
+					$out .= "Droppables.add('alink_".$id."', {hoverclass: 'menudraghover', onDrop: function(element) { var regdrag = /.*(menu)_[0-9]+.*/; regdrag.exec(element.id); if(RegExp.\$1 == 'menu') { var reg = /.*alink_([0-9]+).*/; reg.exec(element.innerHTML); AjaxMoveTree(RegExp.\$1, ".$id."); } else { var reg = /.*contentdragid_([0-9]+).*/; reg.exec(element.id); AjaxMoveContent(RegExp.\$1, ".$id."); } } });";
+					$out .= '}';
+					$out .= "</script>\n";
 				}
 
 				if ((isset ($this->open[$id]) && $this->open[$id] == 1) || $this->expand == 1 || $this->doexpand == 1) {
 					if($this->editor == TRUE) {
 						$out .= $this->getContentTitleOfPage($id,$indent+1,$imagePrefix);
 					}
-					
+
 					$_SESSION['open'][$id] = 1;
 					$this->open[$id] = 1;
 					$out .= $this->showAjaxTreePart( $this->getTreePart( $id ), $indent+1 );
@@ -533,7 +566,9 @@ class categoryTree {
 	}
 
 	/**
-	 *
+	 * create a link
+	 * @param array $link
+	 * @return string return url
 	 */
 	function makeLink($link = array()) {
 		if(is_array($link)) {
@@ -550,6 +585,8 @@ class categoryTree {
 	/**
 	 * return number of parents to root
 	 * needed for tree to show subelements
+	 * @param integer $id
+	 * @return integer
 	 */
 	function getDeepPart($id) {
 		if (isset ($this->allelements[$id]) and $this->allelements[$id] != "" && isset ($this->allelements[$id]) and $this->allelements[$id] != 0) {
@@ -560,52 +597,81 @@ class categoryTree {
 	}
 
 	/**
-	 *
+	 * get part of tree
+	 * @param integer $belongs_to
+	 * @return array
 	 */
 	function getTreePart( $belongs_to ) {
 		// WAAH! ueberfluessig haeufiger Aufruf...mir jetzt egal :)
 		$cats = $this->out;
 		$out = array();
-		if (isset ($cats[ $belongs_to ]) and count( $cats[ $belongs_to ] ) > 0 ) {
-			foreach ( $cats[ $belongs_to ] as $id => $entry ) {
-				$out[$id] = $entry;
+
+		if($this->isSymlink($belongs_to) != 0) {
+			$out = $this->getTreePart($this->isSymlink($belongs_to));
+		} else {
+			if (isset ($cats[ $belongs_to ]) and count( $cats[ $belongs_to ] ) > 0 ) {
+				foreach ( $cats[ $belongs_to ] as $id => $entry ) {
+					$out[$id] = $entry;
+				}
 			}
 		}
 
 		return $out;
 	}
 
+	/**
+	 * check if the id is an symlink
+	 * @param integer $id treeitemid
+	 * @return integer
+	 */
+	function isSymlink($id) {
+		if(isset($this->myelements[$id]['symlink']) && $this->myelements[$id]['symlink'] != "" && $this->myelements[$id]['symlink'] != "0") {
+			return $this->myelements[$id]['symlink'];
+		}
+
+		return 0;
+	}
+
 	/**
 	 * check if the id is the last part in tree
+	 * @param integer $id
+	 * @return bool
 	 */
 	function lastPart($id) {
 		foreach($this->myelements as $key => $value) {
-			if($this->myelements[$key] == $id) {
+			if($this->myelements[$key]['id'] == $id) {
 				return 0;
 			}
 		}
 
+		// check for symlink
+		if($this->isSymlink($id) != 0) {
+			return 0;
+		}
+
 		return 1;
 	}
 
 	/**
 	 * get all content titels of a tree element
+	 * @param integer $pageid
+	 * @param integer $indent
+	 * @param string $imagePrefix
+	 * @return string
 	 */
 	function getContentTitleOfPage($pageid, $indent = 0,$imagePrefix = "") {
-		if($imagePrefix == "") {
-			if ($this->CLASS['vars']['htmleditor']['editor'] == "fckeditor") {
-				$imagePrefix = "../../../../";
-			} else {
-				$imagePrefix = "../../../../../../";
-			}
-		}
-		
+		//$imagePrefix == "";
+		//if(isset($this->CLASS['vars']['include_prefix'])) $imagePrefix = $this->CLASS['vars']['include_prefix'];
+		$imagePrefix = $this->CLASS['knowledgeroot']->getEnv("REQUEST_DIR");
+
 		$out = "";
-		
+
 		// select the content in table content with userrights
 		if (isset ($_SESSION['admin']) and $_SESSION['admin'] == 1) {
 			if($this->CLASS['db']->dbtype == "pgsql") {
 				$query = sprintf("SELECT ct.id as id, ct.content as content, ct.title as title, ct.type as type, u.name as lastupdatedby, to_char(ct.lastupdated,'DD. Mon YYYY HH24:MI:SS') as lastupdated FROM content ct left outer join users u ON ct.lastupdatedby = u.id WHERE belongs_to=%d AND ct.deleted=0 ORDER BY ct.sorting ASC",$pageid);
+			} elseif($this->CLASS['db']->dbtype == "sqlite") {
+				$query = sprintf("SELECT ct.id as id, ct.content as content, ct.title as title, ct.type as type, u.name as lastupdatedby, strftime('%%d.%%m.%%Y %%H:%%M:%%S',ct.lastupdated) as lastupdated FROM content ct left outer join users u ON ct.lastupdatedby = u.id WHERE belongs_to=%d AND ct.deleted=0 ORDER BY ct.sorting ASC",$pageid);
 			} else {
 				$query = "SELECT ct.id AS id, ct.content AS content, ct.title AS title, ct.type AS type, u.name AS lastupdatedby, DATE_FORMAT(ct.lastupdated,'%d. %M %Y %H:%i:%s') as lastupdated FROM content ct";
 				$query .= sprintf(" LEFT OUTER JOIN users u ON ct.lastupdatedby = u.id WHERE belongs_to=%d AND ct.deleted=0 ORDER BY ct.sorting ASC", $pageid);
@@ -615,36 +681,34 @@ class categoryTree {
 			$res = $this->CLASS['db']->query(sprintf("SELECT groupid FROM user_group WHERE userid=%d",$_SESSION['userid']));
 			$orclause = "";
 			while($rowuser = $this->CLASS['db']->fetch_assoc($res)) {
-				if($this->CLASS['db']->dbtype == "pgsql") {
-					$orclause .= sprintf("OR (ct.\"group\"=%d  AND ct.grouprights > 0) ",$rowuser['groupid']);
-				} else {
-					$orclause .= sprintf("OR (ct.`group`=%d  AND ct.grouprights > 0) ",$rowuser['groupid']);
-				}
+				$orclause .= sprintf("OR (ct.".$this->CLASS['db']->quoteIdentifier("group")."=%d  AND ct.grouprights > 0) ",$rowuser['groupid']);
 			}
-	
+
 			if($this->CLASS['db']->dbtype == "pgsql") {
-				$query = sprintf("SELECT ct.id as id, ct.content as content, ct.title as title, ct.type as type, u.name as lastupdatedby, to_char(ct.lastupdated,'DD. Mon YYYY HH24:MI:SS') as lastupdated FROM content ct left outer join users u ON ct.lastupdatedby = u.id WHERE belongs_to=%d AND ct.deleted=0 AND ((ct.otherrights > 0) OR (ct.\"group\"=%d AND ct.grouprights > 0) %sOR (ct.owner=%d AND ct.userrights>0)) ORDER BY ct.sorting ASC",$pageid,$_SESSION['groupid'],$orclause,$_SESSION['userid']);
+				$query = sprintf("SELECT ct.id as id, ct.content as content, ct.title as title, ct.type as type, u.name as lastupdatedby, to_char(ct.lastupdated,'DD. Mon YYYY HH24:MI:SS') as lastupdated FROM content ct left outer join users u ON ct.lastupdatedby = u.id WHERE belongs_to=%d AND ct.deleted=0 AND ((ct.otherrights > 0) OR (ct.".$this->CLASS['db']->quoteIdentifier("group")."=%d AND ct.grouprights > 0) %sOR (ct.owner=%d AND ct.userrights>0)) ORDER BY ct.sorting ASC",$pageid,$_SESSION['groupid'],$orclause,$_SESSION['userid']);
+			} elseif($this->CLASS['db']->dbtype == "sqlite") {
+				$query = sprintf("SELECT ct.id as id, ct.content as content, ct.title as title, ct.type as type, u.name as lastupdatedby, strftime('%%d.%%m.%%Y %%H:%%M:%%S',ct.lastupdated) as lastupdated FROM content ct left outer join users u ON ct.lastupdatedby = u.id WHERE belongs_to=%d AND ct.deleted=0 AND ((ct.otherrights > 0) OR (ct.".$this->CLASS['db']->quoteIdentifier("group")."=%d AND ct.grouprights > 0) %sOR (ct.owner=%d AND ct.userrights>0)) ORDER BY ct.sorting ASC",$pageid,$_SESSION['groupid'],$orclause,$_SESSION['userid']);
 			} else {
 				$query = "SELECT ct.id AS id, ct.content AS content, ct.title AS title, ct.type AS type, u.name AS lastupdatedby, DATE_FORMAT(ct.lastupdated,'%d. %M %Y %H:%i:%s') AS lastupdated FROM content ct";
-				$query .= sprintf(" LEFT OUTER JOIN users u ON ct.lastupdatedby = u.id WHERE belongs_to=%d AND ct.deleted=0 AND ((ct.otherrights > 0) OR (ct.`group`=%d AND ct.grouprights > 0) %s OR (ct.owner=%d AND ct.userrights>0)) ORDER BY ct.sorting ASC",
+				$query .= sprintf(" LEFT OUTER JOIN users u ON ct.lastupdatedby = u.id WHERE belongs_to=%d AND ct.deleted=0 AND ((ct.otherrights > 0) OR (ct.".$this->CLASS['db']->quoteIdentifier("group")."=%d AND ct.grouprights > 0) %s OR (ct.owner=%d AND ct.userrights>0)) ORDER BY ct.sorting ASC",
 				$pageid, $_SESSION['groupid'], $orclause,$_SESSION['userid']);
 			}
 		}
 
 		$res = $this->CLASS['db']->query($query);
-	
+
 		$space = "";
 		for ( $i=0; $i<$indent; $i++ ) {
-			$space .= "&nbsp;<img src=\"".$imagePrefix."images/clear.gif\" width=\"9\" height=\"9\" alt=\"\" />&nbsp;";
+			$space .= "&nbsp;<img src=\"".$imagePrefix."images/clear.gif\" alt=\"\" width=\"9\" height=\"9\" />&nbsp;";
 		}
-		
-		$spaces = $space . "&nbsp;<img class=\"bullet\" widht=\"16\" height=\"16\" alt=\"\" src=\"".$imagePrefix."images/pages.gif\" />&nbsp;";
-		
+
+		$spaces = $space . "&nbsp;<img class=\"bullet\" alt=\"\" width=\"16\" height=\"16\" src=\"".$imagePrefix."images/pages.gif\" />&nbsp;";
+
 		while($row = $this->CLASS['db']->fetch_assoc($res)) {
 			if($row['title'] == "") $row['title'] = $row['type'] . " (ID:".$row['id'].")";
 			$out .= "<tr id=\"contenttreeid_".$row['id']."\"><td>" . $spaces . "<a href=\"javascript:;\" onclick=\"editorSelect('index.php?contentid=".$row['id']."#".$row['id']."', '".$row['title']."');\">" . $row['title']."</a></td></tr>\n";
 		}
-		
+
 		return $out;
 	}
 }
