@@ -5,24 +5,29 @@
  * @package Knowledgeroot
  * @author Frank Habermann <lordlamer@lordlamer.de>
  * @author Robert Scholz <scholzrobert@web.de>
- * @version $Id: index.php 357 2007-04-22 18:13:45Z lordlamer $
+ * @version $Id: index.php 786 2009-07-31 20:48:26Z lordlamer $
  */
 
-if(!is_file("config/config.inc.php")) {
+// timer
+$timer = microtime();
+$starttime = ((double)strstr($timer, ' ') + (double)substr($timer,0,strpos($timer,' ')));
+
+if (!is_file("config/config.inc.php")) {
 	echo "<html><body>No configuration file found! Please make a <a href=\"install.php\">install</a>!</body></html>";
 	exit();
 }
 
 // load requiered files
-require_once("config/config.inc.php");
-require_once("include/init.php");
+require_once ('config/config.inc.php');
+require_once ('include/init.php');
+
 
 /********************
  * This is the end of initialisation
  * Now do header work
  ********************/
 
-if($CLASS['vars']['knowledgeroot']['charset'] != "") {
+if ($CLASS['vars']['knowledgeroot']['charset'] != '') {
   header("Content-Type: text/html; charset=".$CLASS['vars']['knowledgeroot']['charset']."");
   echo '<?xml version="1.0" encoding="'.$CLASS['vars']['knowledgeroot']['charset'].'"?>';
 } else {
@@ -43,9 +48,12 @@ echo "\n";
 <body <?php if($CLASS['vars']['menu']['type'] == "slide") { echo "onload=\"Hide('tree');\""; } ?>>
 
 <div style="display: none;" id="messagebox">
-  <div id="msg" class="loading"><?php echo $CLASS['language']->get['messagebox']['loading']; ?></div>
+  <div id="msg" class="loading"><?php echo T_('loading...'); ?></div>
 </div>
 
+<div id="mousemenu" style="display: none; position: absolute;">&nbsp;</div>
+<div id="dragbox" style="display: none; position: absolute;">&nbsp;jauhau</div>
+
 <a name="top"></a>
 <table border="0" cellpadding="0" cellspacing="0" width="100%">
 	<tr class="head">
@@ -54,18 +62,18 @@ echo "\n";
 				<tr>
 					<td>
 						<div class="pagetitle">
-							<?php echo $CLASS['vars']['knowledgeroot']['title']; ?>
+							<?php echo (isset($CLASS['vars']['knowledgeroot']['showlogo']) && $CLASS['vars']['knowledgeroot']['showlogo'] == "1") ? "<img src=\"images/knowledgeroot_logo.png\" alt=\"".$CLASS['vars']['knowledgeroot']['title']."\" title=\"".$CLASS['vars']['knowledgeroot']['title']."\" />" : $CLASS['vars']['knowledgeroot']['title']; ?>
 						</div>
 					</td>
 					<td align="right" valign="bottom">
 						<div class="version">
-							<a href="http://www.linuxdelta.de/Knowledgeroot.html">Knowledgeroot</a> - <?php echo $CLASS['language']->get['version'] . ":&nbsp;" . $version; ?>
+							<a href="http://www.knowledgeroot.org">Knowledgeroot</a> - <?php echo T_('version')/* $CLASS['language']->get['version'] */ . ":&nbsp;" . $version; ?>
 						</div>
 						<div class="mainnavi">
 						<?php
 						  // show top menu
-						  // $CLASS['kr_content']->show_menu();
-						  $CLASS['kr_extension']->show_menu("top");
+						  // echo $CLASS['kr_content']->show_menu();
+						  echo $CLASS['kr_extension']->show_menu("top");
 						?>
 						</div>
 					</td>
@@ -77,7 +85,7 @@ echo "\n";
 	<tr class="navigationpath">
 		<td class="navigation" colspan="2">
 			<div class="navigationleft">
-				<b><?php echo $CLASS['language']->get['path']; ?>:
+				<b><?php echo T_('Path'); ?>:
 	<?php
 	  // show path
 	  if($CLASS['knowledgeroot']->checkRecursivPerm($_SESSION['cid'], $_SESSION['userid']) != 0) {
@@ -91,13 +99,13 @@ echo "\n";
 
 			</b>
 		</div>
-		<div class="navigationright"><?php echo $CLASS['language']->get['user'] . ":&nbsp;" . $_SESSION['user']; ?>&nbsp;</div>
+		<div class="navigationright"><?php echo T_('User')  . ":&nbsp;" . $_SESSION['user']; ?>&nbsp;</div>
 		<div class="navigationmiddle">
 		<form action="index.php" method="post">
-	  	<?php echo $CLASS['language']->get['search']; ?>:
-			<input class="searchfield" type="text" name="search" value="<?php if(isset ($_POST['search']) and $_POST['search'] != "") { echo htmlspecialchars(stripslashes($_POST['search'])); } ?>" />
-			<input type="hidden" name="submit" value="GO"><?php /* FIXED BUG: #39 */ ?>
-			<input class="searchgo" type="submit" name="submit" value="<?php echo $CLASS['language']->get['searchgo']; ?>" />
+	  	<?php echo T_('Search'); ?>:
+			<input class="searchfield" type="text" name="search" value="<?php if(isset ($_GET['action']) && $_GET['action'] == "showsearch" && isset ($_GET['key']) && $_GET['key'] != "" && isset($_SESSION['search'][$_GET['key']])) { echo str_replace('&amp;quot;','&quot;',htmlspecialchars(stripslashes($_SESSION['search'][$_GET['key']]))); } ?>" />
+			<input type="hidden" name="submit" value="GO" /><?php /* FIXED BUG: #39 */ ?>
+			<input class="searchgo" type="submit" name="submit" value="<?php echo T_('GO'); ?>" />
 		</form>
 		</div>
 	<?php
@@ -130,7 +138,7 @@ echo "\n";
 	   <!-- <a href="#" onClick="ShowHide('tree');">#</a> -->
 	  <div id="treeopener" <?php if($CLASS['vars']['menu']['type'] == "static") { echo "style=\"display:none;\""; } else { echo "style=\"display:block;\""; } ?>>
 	    <div id="treeshow">
-	      <a href="#" onclick="ShowTree();"><img id="treeshowimg" src="images/right.gif" width="22" alt="<?php echo $CLASS['language']->get['tree']['showtree']; ?>" title="<?php echo $CLASS['language']->get['tree']['showtree']; ?>" /></a>
+	      <a href="#" onclick="ShowTree();"><img id="treeshowimg" src="images/right.gif" width="22" alt="<?php echo T_('show menu'); ?>" title="<?php echo T_('show menu'); ?>" /></a>
 	    </div>
 	  </div>
 
@@ -161,9 +169,9 @@ echo "\n";
     echo "<p>"."\n";
     echo "developer toolbar: <a href=\"http://forum.linuxdelta.de\" target=\"_blank\">forum</a>"."\n";
     echo "<a href=\"http://lists.linuxdelta.de/cgi-bin/mailman/listinfo\" target=\"_blank\">mailinglist</a>"."\n";
-    echo "<a href=\"http://www.knowledgeroot.de\" target=\"_blank\">project page</a>"."\n";
+    echo "<a href=\"http://www.knowledgeroot.org\" target=\"_blank\">project page</a>"."\n";
     echo "<a href=\"http://www.linuxdelta.de/knowledgeroot.html\">homepage</a>"."\n";
-    $CLASS['kr_extension']->show_menu("toolbar");
+    echo $CLASS['kr_extension']->show_menu("toolbar");
     echo "</p>"."\n";
     echo "</div>\n";
   }
@@ -176,8 +184,17 @@ echo "\n";
     echo "querys: " . $CLASS['db']->querys;
     echo $CLASS['error']->view_array($CLASS['db']->query_cache);
   }
+$res = $CLASS['db']->query("SELECT * FROM content");
   // close db connection
   $CLASS['db']->close();
+
+  if(isset($CLASS['vars']['dev']['showruntime']) && $CLASS['vars']['dev']['showruntime'] == 1) {
+    $timer = microtime();
+    $stoptime = ((double)strstr($timer, ' ') + (double)substr($timer,0,strpos($timer,' ')));
+    echo "<!-- runtime: ".sprintf('%2.3f', $stoptime - $starttime)." -->";
+  }
+//echo $CLASS['error']->view_array($_SESSION);
+//echo serialize($_SESSION['open']);
 ?>
 </body>
 </html>
