@@ -32,17 +32,17 @@ if($CLASS['vars']['knowledgeroot']['charset'] != "") {
 <body>
 
 <div style="display: none;" id="messagebox">
-	<div id="msg" class="loading"><?php echo $CLASS['language']->get['messagebox']['loading']; ?></div>
+	<div id="msg" class="loading"><?php echo T_('loading...'); ?></div>
 </div>
 
 <div class="movetitle">
-<?php echo $CLASS['language']->get['moveto']; ?>
+<?php echo T_('move to'); ?>
 </div>
 <?php
 if(isset($_SESSION['admin']) && $_SESSION['admin'] == 1 && isset($_GET['type']) && $_GET['type'] == "page") {
 ?>
 <div id="toroot">
-<input class="button" onclick="window.opener.document.forms.move.to.value = '0'; window.opener.document.forms.move.submit(); window.close();" type="button" name="submit" value="<?php echo $CLASS['language']->get['movetoroot']; ?>">
+<input class="button" onclick="window.opener.document.forms.move.to.value = '0'; window.opener.document.forms.move.submit(); window.close();" type="button" name="submit" value="<?php echo T_('move to root'); ?>">
 </div>
 <?php
 }
@@ -52,7 +52,7 @@ if(isset($_SESSION['admin']) && $_SESSION['admin'] == 1 && isset($_GET['type'])
  	<!-- <a href="#" onClick="ShowHide('tree');">#</a> -->
 	<div id="treeopener" <?php if($CLASS['vars']['menu']['type'] == "static") { echo "style=\"display:none;\""; } else { echo "style=\"display:block;\""; } ?>>
 		<div id="treeshow">
-			<a href="#" border="0" onclick="ShowTree();" alt="<?php echo $CLASS['language']->get['tree']['showtree']; ?>"><img id="treeshowimg" src="images/right.gif" width="22" title="<?php echo $CLASS['language']->get['tree']['showtree']; ?>" /></a>
+			<a href="#" border="0" onclick="ShowTree();" alt="<?php echo T_('show menu'); ?>"><img id="treeshowimg" src="images/right.gif" width="22" title="<?php echo T_('show menu'); ?>" /></a>
 		</div>
 	</div>
 
@@ -66,7 +66,7 @@ if(isset($_SESSION['admin']) && $_SESSION['admin'] == 1 && isset($_GET['type'])
  </td>
 </tr></table>
 <div id="toroot">
-<input class="button" onclick="window.close();" type="button" name="submit" value="<?php echo $CLASS['language']->get['moveclose']; ?>">
+<input class="button" onclick="window.close();" type="button" name="submit" value="<?php echo T_('close window'); ?>">
 </div>
 </body>
 </html>
