@@ -6,9 +6,9 @@
 
 	function AjaxMenuOpen(id,move,path,editor) {
 		ShowMessage(msgboxloading, "loading");
-		
+
 		script = path + "ajax-xml.php";
-		
+
 		var ajaxopen = new Ajax.Request(
 			script,
 			{
@@ -25,9 +25,9 @@
 
 	function AjaxMenuClose(id,move,path,editor) {
 			ShowMessage(msgboxloading, "loading");
-			
+
 			script = path + "ajax-xml.php";
-			
+
 			var ajaxopen = new Ajax.Request(
 				script,
 				{
@@ -54,7 +54,7 @@
 				new Insertion.After('menu_'+id, data);
 			} else if (document.all) {
 				var data = unescape(r.responseXML.getElementsByTagName("html")[0].firstChild.nodeValue);
-				new Insertion.Bottom('menu_'+id, data);
+				new Insertion.After('menu_'+id, data);
 			} else {
 				var data = unescape(root[0].getElementsByTagName("html")[0].textContent);
 				new Insertion.After('menu_'+id, data);
@@ -83,15 +83,15 @@
 				// extra function because fucking ie is so stupid
 				removeElement("menu_"+id);
 			}
-			
+
 			// remove content elements
 			var contents = root[0].getElementsByTagName("content");
-			
+
 			for(var i=0; i<contents.length; i++) {
 				var id = root[0].getElementsByTagName("content")[i].firstChild.data;
 				removeElement("contenttreeid_"+id);
 			}
-			
+
 			HideMessage("loading");
 		} catch (e) {
 			ShowMessage(e.message + "#" + e.name + "#" + e.number, "error");
@@ -193,4 +193,68 @@
 			ShowMessage(e.message + "#" + e.name + "#" + e.number, "error");
 			setTimeout("HideMessage()", 7000);
 		}
-	}
\ No newline at end of file
+	}
+
+	var AjaxMoveTree = function(source, destination) {
+		if(source != destination) {
+			ShowMessage(msgboxloading, "loading");
+
+			script = "ajax-xml.php";
+
+			var ajaxopen = new Ajax.Request(
+				script,
+				{
+					method:'post',
+					postBody: 'action=ajaxmove&source='+source+'&destination='+destination,
+					onComplete:showReloadTree,
+					onFailure:showError
+				}
+			);
+		}
+	}
+
+	var AjaxMoveContent = function(source, destination) {
+		ShowMessage(msgboxloading, "loading");
+
+		script = "ajax-xml.php";
+
+		var ajaxopen = new Ajax.Request(
+			script,
+			{
+				method:'post',
+				postBody: 'action=ajaxmovecontent&source='+source+'&destination='+destination,
+				onComplete:showMoveTree,
+				onFailure:showError
+			}
+		);
+	}
+
+	var showMoveTree = function(r) {
+		try {
+			var root = r.responseXML.getElementsByTagName("root");
+			if(navigator.appName == "Opera" || navigator.appName == "opera") {
+				var action = unescape(root[0].getElementsByTagName("action")[0].textContent);
+			} else if (document.all) {
+				var action = unescape(r.responseXML.getElementsByTagName("action")[0].firstChild.nodeValue);
+			} else {
+				var action = unescape(root[0].getElementsByTagName("action")[0].textContent);
+			}
+
+			if(action == "contentremove") {
+				if(navigator.appName == "Opera" || navigator.appName == "opera") {
+					var contentid = unescape(root[0].getElementsByTagName("element")[0].textContent);
+				} else if (document.all) {
+					var contentid = unescape(r.responseXML.getElementsByTagName("element")[0].firstChild.nodeValue);
+				} else {
+					var contentid = unescape(root[0].getElementsByTagName("element")[0].textContent);
+				}
+
+				Element.remove("contentid_" + contentid);
+			}
+
+			HideMessage("loading");
+		} catch (e) {
+			ShowMessage(e.message + "#" + e.name + "#" + e.number, "error");
+			setTimeout("HideMessage()", 7000);
+		}
+	}
