@@ -1,8 +1,10 @@
-/*
-	Knowledgeroot
-	Frank Habermann
-	This file includes functions to show the messagebox
-*/	
+/**
+ * Javascript to show messagebox
+ * Knowledgeroot
+ * Frank Habermann
+ * 20080103
+ */
+
 	var ShowMessage = function(msg, type) {
 		$("messagebox").style.display = "block";
 		$("msg").className = type;
@@ -13,7 +15,7 @@
 		}
 		
 	}
-	
+
 	var HideMessage = function(type) {
 		if(type != "loading") {
 			Effect.BlindUp('messagebox',{duration:1.0});
