@@ -21,8 +21,7 @@ function ShowById(id) {
 }
 
 function ExpandOrCollapseContent(o, collapseId) {
-
-    var ip = o.parentNode;
+	var ip = o.parentNode;
 	var p = ip.parentNode;
 	p = p.parentNode;
 	var children = p.getElementsByTagName("div");
@@ -40,3 +39,29 @@ function ExpandOrCollapseContent(o, collapseId) {
 	}
 	return false;
 }
+
+function CollapseContent(o, collapseId) {
+	var ip = o.parentNode;
+	var p = ip.parentNode;
+	p = p.parentNode;
+	var children = p.getElementsByTagName("div");
+	var im = ip.getElementsByTagName("img")[0];
+
+	im.src = 'images/plus.jpg';
+	document.getElementById(collapseId).style.display = "none";
+
+	return false;
+}
+
+function ExpandContent(o, collapseId) {
+	var ip = o.parentNode;
+	var p = ip.parentNode;
+	p = p.parentNode;
+	var children = p.getElementsByTagName("div");
+	var im = ip.getElementsByTagName("img")[0];
+
+	im.src = 'images/minus.jpg';
+	document.getElementById(collapseId).style.display = "block";
+
+	return false;
+}
